@@ -10,14 +10,14 @@ MIT License (see LICENSE.txt)
 
 void* create_mutex() {
   void* mutex;
-  mutex = PyMem_Malloc(sizeof(pthread_mutex_t));
+  mutex = PyMem_RawMalloc(sizeof(pthread_mutex_t));
   pthread_mutex_init((pthread_mutex_t*)mutex, NULL);
   return mutex;
 }
 
 void destroy_mutex(void* mutex) {
   pthread_mutex_destroy((pthread_mutex_t*)mutex);
-  PyMem_Free(mutex);
+  PyMem_RawFree(mutex);
 }
 
 void grab_mutex(void* mutex) {
